<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use DateTime;
use DateTimeInterface;
use Sylius\Component\Customer\Model\CustomerInterface;
use Sylius\Component\Resource\Model\ResourceInterface;
use Symfony\Component\Validator\Constraints as Assert;

class Comment implements CommentInterface, ResourceInterface
{
    protected ?int $id = null;

    /** @Assert\NotBlank(groups={"default", "sylius"}) */
    protected string $content = '';

    protected ?CustomerInterface $customer;

    protected ?ArticleInterface $article;

    protected DateTimeInterface $createdAt;

    protected string $status = CommentInterface::STATUS_NEW;

    public function __construct()
    {
        $this->createdAt = new DateTime();
    }

    public function getContent(): string
    {
        return $this->content;
    }

    public function setContent(string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getArticle(): ArticleInterface
    {
        return $this->article;
    }

    public function setArticle(ArticleInterface $article): self
    {
        $this->article = $article;

        return $this;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getCustomer(): ?CustomerInterface
    {
        return $this->customer;
    }

    public function setCustomer(?CustomerInterface $customer): self
    {
        $this->customer = $customer;

        return $this;
    }

    public function setCreatedAt(DateTimeInterface $createdAt): self
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    public function getCreatedAt(): DateTimeInterface
    {
        return $this->createdAt;
    }

    public function setStatus(string $status): void
    {
        $this->status = $status;
    }

    public function getStatus(): string
    {
        return $this->status;
    }
}
